@@ -1,12 +1,21 @@
 package Perinci::Object::Metadata;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.24'; # VERSION
+our $DATE = '2017-02-03'; # DATE
+our $VERSION = '0.30'; # VERSION
 
 use 5.010;
 use strict;
 use warnings;
-use String::Trim::More qw(trim_blank_lines);
+
+# BEGIN COPY-PASTE FROM String::Trim::More
+sub __trim_blank_lines {
+    local $_ = shift;
+    return $_ unless defined;
+    s/\A(?:\n\s*)+//;
+    s/(?:\n\s*){2,}\z/\n/;
+    $_;
+}
+# END COPY-PASTE
 
 sub new {
     my ($class, $meta) = @_;
@@ -68,7 +77,7 @@ sub langprop {
                 my $has_nl = $v =~ s/\n\z//;
                 $v = "{$olang|$k->[0] $v}" . ($has_nl ? "\n" : "");
             }
-            $v = trim_blank_lines($v);
+            $v = __trim_blank_lines($v);
             last GET;
         }
     }
@@ -140,7 +149,7 @@ Perinci::Object::Metadata - Base class for Perinci::Object metadata classes
 
 =head1 VERSION
 
-This document describes version 0.24 of Perinci::Object::Metadata (from Perl distribution Perinci-Object), released on 2015-09-03.
+This document describes version 0.30 of Perinci::Object::Metadata (from Perl distribution Perinci-Object), released on 2017-02-03.
 
 =head1 METHODS
 
@@ -221,7 +230,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
